==> andyreagan-0.2.0.tar.gz: andyreagan-0.2.0/README.md <==
#+TITLE: andyreagan
#+AUTHOR: Andy Reagan

A simple Python package that prints Andy Reagan's resume to the command line when run via ~uvx~.

# Installation

You can run this package directly with ~uvx~ without installation:

```bash
uvx andyreagan
```

Or install it from PyPI:

```bash
pip install andyreagan
```

Then run:

```bash
andyreagan
```

# Usage

Simply run the command to see Andy's resume:

```bash
$ uvx andyreagan
╔═══════════════════════════════════════════════════════════════════════════════╗
║                                 ANDY REAGAN                                   ║
╠═══════════════════════════════════════════════════════════════════════════════╣
║                         Senior Data Scientist & Educator                     ║
╚═══════════════════════════════════════════════════════════════════════════════╝

📍 Location: Springfield, MA
🏢 Current Role: Senior Data Scientist, MassMutual Data Science Program
🎓 Education: Ph.D. Applied Mathematics (Complex Systems), University of Vermont
...
```

# Development

To develop this package locally:

```bash
git clone https://github.com/andyreagan/uvx-andyreagan
cd uvx-andyreagan
uvx --from . andyreagan
```

# About Andy

Andy Reagan is a Senior Data Scientist at MassMutual and educator at UC Berkeley. He holds a Ph.D. in Applied Mathematics with a focus on Complex Systems from the University of Vermont. His research includes sentiment analysis, data visualization, and sociotechnical systems analysis.

# License

This project is released under the MIT License.

==> andyreagan-0.2.1.tar.gz: andyreagan-0.2.1/README.md <==
A simple Python package that prints Andy Reagan\'s resume to the command
line when run via `uvx`.

# Installation

You can run this package directly with `uvx` without installation:

``` bash
uvx andyreagan
```

Or install it from PyPI:

``` bash
pip install andyreagan
```

Then run:

``` bash
andyreagan
```

# Usage

Simply run the command to see Andy\'s resume:

``` bash
$ uvx andyreagan
╔═══════════════════════════════════════════════════════════════════════════════╗
║                                 ANDY REAGAN                                   ║
╠═══════════════════════════════════════════════════════════════════════════════╣
║                         Senior Data Scientist & Educator                     ║
╚═══════════════════════════════════════════════════════════════════════════════╝

📍 Location: Springfield, MA
🏢 Current Role: Senior Data Scientist, MassMutual Data Science Program
🎓 Education: Ph.D. Applied Mathematics (Complex Systems), University of Vermont
...
```

# Development

To develop this package locally:

``` bash
git clone https://github.com/andyreagan/uvx-andyreagan
cd uvx-andyreagan
uvx --from . andyreagan
```

# About Andy

Andy Reagan is a Senior Data Scientist at MassMutual and educator at UC
Berkeley. He holds a Ph.D. in Applied Mathematics with a focus on
Complex Systems from the University of Vermont. His research includes
sentiment analysis, data visualization, and sociotechnical systems
analysis.

# License

This project is released under the MIT License.
